@@ -1,12 +1,11 @@
 
 import pkg_resources
 
-import BPTK_Py.systemdynamics.functions as sd_functions
-from .abm import Event, DelayedEvent, Agent, DataCollector, Model, Scheduler, SimultaneousScheduler
+import BPTK_Py.sddsl.functions as sd_functions
+from .modeling import Event, DelayedEvent, Agent, DataCollector, Model, Scheduler, SimultaneousScheduler
 from .bptk import bptk, conf
 from .config import config
 from .logger import log
-from .remote import connect
 from .server import BptkServer
 
 try:
